"""Django e-mail SMTP backend with DKIM signing."""
from __future__ import absolute_import, division, print_function, unicode_literals

import smtplib
from builtins import bytes

import dkim
from django.conf import settings
from django.core.mail.backends.smtp import EmailBackend as SMTPEmailBackend
from django.core.mail.message import sanitize_address


class EmailBackend(SMTPEmailBackend):
    """SMTP backend that signs the message with DKIM."""

    def _send(self, email_message):
        """Do actual sending and DKIM signing."""
        if not email_message.recipients():
            return False
        encoding = email_message.encoding or settings.DEFAULT_CHARSET
        from_email = sanitize_address(email_message.from_email, encoding)
        recipients = [sanitize_address(addr, encoding) for addr in email_message.recipients()]
        message = email_message.message()
        try:
            message_string = message.as_bytes(linesep='\r\n')
            signature = dkim.sign(message_string,
                                  bytes(settings.DKIM_SELECTOR, 'ascii'),
                                  bytes(settings.DKIM_DOMAIN, 'ascii'),
                                  bytes(settings.DKIM_PRIVATE_KEY, 'ascii'))
            self.connection.sendmail(from_email, recipients, signature + message_string)
        except (smtplib.SMTPException, dkim.DKIMException):
            if not self.fail_silently:
                raise
            return False
        return True



#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""Setup script for django_dkim."""
import os

from setuptools import find_packages, setup

import django_dkim


def readme():
    """Return content of README file."""
    with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as f:
        return f.read()


INSTALL_REQUIRES = ['Django>=1.11', 'dkimpy', 'future']
EXTRAS_REQUIRE = {'quality': ['flake8', 'isort', 'pydocstyle'],
                  'test': ['mock']}

setup(name='django-dkim',
      version=django_dkim.__version__,
      description='DKIM signing e-mail backend for Django',
      long_description=readme(),
      url='https://gitlab.com/stinovlas/django-dkim',
      author='Jan Musílek',
      author_email='stinovlas@gmail.com',
      packages=find_packages(),
      install_requires=INSTALL_REQUIRES,
      extras_require=EXTRAS_REQUIRE,
      python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, <4',
      classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 2.2',
        'Framework :: Django :: 3.0',
        'Framework :: Django :: 3.1',
        'Framework :: Django :: 3.2',
        'Framework :: Django :: 4.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
      ])
